(convert converter amount from)(convert converter amount from to)(convert converter amount from to date)Convert amount from currency from to currency to on date.
If date is omitted, uses the last available date for from.
If to is omitted, uses ref-currency (EUR).
Convert amount from currency `from` to currency `to` on `date`. If date is omitted, uses the last available date for `from`. If `to` is omitted, uses ref-currency (EUR).
(cross-rate converter currency-a currency-b date)Return the cross rate from currency-a to currency-b on date.
Return the cross rate from currency-a to currency-b on date.
(get-rate converter currency date)Return the EUR-referenced rate for currency on date.
Return the EUR-referenced rate for currency on date.
(make-converter)(make-converter source)(make-converter source opts)Build a converter map from a source. source: nil (default) fetches latest data from ECB URL, or pass a URL string or file path. opts: map with keys :fallback-on-wrong-date, :ref-currency, :cast-fn, :na-values.
Build a converter map from a source. source: nil (default) fetches latest data from ECB URL, or pass a URL string or file path. opts: map with keys :fallback-on-wrong-date, :ref-currency, :cast-fn, :na-values.
(make-converter-from-lines lines)(make-converter-from-lines lines opts)Build a converter from an already-loaded seq of CSV lines.
Build a converter from an already-loaded seq of CSV lines.
(rate-history {:keys [rates]} currency)Return the full sorted-map of {date rate} for a currency.
Return the full sorted-map of {date rate} for a currency.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |